jicarilla-sandbox/platform/framework/impl/src/java/org/jicarilla/framework/plumbing SimpleAlternator.java,1.1,1.2
Leo Simons <[email protected]>
| Newsgroups | gmane.comp.java.jicarilla.cvs |
|---|---|
| Message-ID | <[email protected]> |
Update of /cvsroot/jicarilla/jicarilla-sandbox/platform/framework/impl/src/java/org/jicarilla/framework/plumbing
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv17849/platform/framework/impl/src/java/org/jicarilla/framework/plumbing
Modified Files:
SimpleAlternator.java
Log Message:
move o.j.f.Alternator to o.j.f.p.Alternator where it belongs
Index: SimpleAlternator.java
===================================================================
RCS file: /cvsroot/jicarilla/jicarilla-sandbox/platform/framework/impl/src/java/org/jicarilla/framework/plumbing/SimpleAlternator.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- SimpleAlternator.java 5 Jan 2004 15:41:51 -0000 1.1
+++ SimpleAlternator.java 22 Mar 2004 15:52:36 -0000 1.2
@@ -55,14 +55,14 @@
package org.jicarilla.framework.plumbing;
import org.jicarilla.framework.plumbing.Sink;
-import org.jicarilla.framework.Alternator;
+import org.jicarilla.framework.plumbing.Alternator;
import org.jicarilla.framework.Assert;
import java.util.ArrayList;
import java.util.List;
/**
* A list-backed {@link org.jicarilla.framework.Alternator} which uses the priority as a weight. In
* other words, a sink with priority <i>2*n</i> has twice the chance of being
* selected compared to a sink with priority <i>n</i>).
*
-------------------------------------------------------
This SF.Net email is sponsored by: IBM Linux Tutorials
Free Linux tutorial presented by Daniel Robbins, President and CEO of
GenToo technologies. Learn everything from fundamentals to system
@@ -55,14 +55,14 @@
import java.util.List;
/**
- * A list-backed {@link org.jicarilla.framework.Alternator} which uses the priority as a weight. In
+ * A list-backed {@link org.jicarilla.framework.plumbing.Alternator} which uses the priority as a weight. In
* other words, a sink with priority <i>2*n</i> has twice the chance of being
* selected compared to a sink with priority <i>n</i>).
administration.http://ads.osdn.com/?ad_id=1470&alloc_id=3638&op=click